#!/bin/sh

#
# Print script usage and exit
#
usage(){
  local flag=$1
  local self=`basename $0`
  cat << HERE
Wrap markdown.pl (or another LML translator) and catch its output.

Usage: ${self} <command> <from_file> f <to_file> t

Options:

<command>   - Translation command.
<from_file> - File to convert to HTML.
f           - A literal lowercase F.
<to_file>   - File to save converted output in.
t           - A literal lowercase T.

This is a wrapper for translation commands that dump their output to
stdout and expect it to be piped where needed, without the ability to
specify a destination file name directly.

Specify file names with all necessary paths, either absolute or relative
to the current directory, not relative to the directory in which
${self} lives.

HERE
  if [ -n "${flag}" ]; then exit 0; else exit 1; fi
}

#
# Find only the command in ${XLAT}, not any of its parameters
#
whichfile(){
  which -s $1
  return $?
}

#
# Basic tools check
#
which -s which || { echo "No 'which' command."; exit 1; }
[ 0 -eq 0 ]    || { echo "The '[' command doesn't work."; exit 1; } # ]
which -s basename || { echo "No 'basename' command."; exit 1; }

#
# Process command line options
#
unset FROM_FILE TO_FILE XLAT
if [     -z "$1" ]; then usage; else XLAT="$1"; fi
if [     -z "$2" ]; then usage; else FROM_FILE="$2"; fi
if [ "f" != "$3" ]; then usage; fi
if [     -z "$4" ]; then usage; else TO_FILE="$4"; fi
if [ "t" != "$5" ]; then usage; fi

#
# Perform translation
#
whichfile ${XLAT}   || { echo "Command '${XLAT}' not found."; exit 1; }
[ -f ${FROM_FILE} ] || { echo "File ${FROM_FILE} not found."; exit 1; }
${XLAT} ${FROM_FILE} > ${TO_FILE}
[ -f ${TO_FILE} ]   || { echo "File ${TO_FILE} not written."; exit 1; }

