#!/bin/sh

#
# Print script usage and exit
#
usage(){
  local flags=$1
  local self=`basename $0`
  cat << HERE
Run python's simple Web server on 127.0.0.1:8080 so you can test that
the site was built correctly (and hopefully catch mistakes and typos)
before you upload the site's changes.

Usage: ${self} <options>

Options:

-h or -?      - Show this help text and exit without error.
-d <dest_dir> - Directory containing the built site to test.
-p <python>   - Name of python binary on this system.

Directory options are either absolute paths or paths relative to the
current directory, not the directory in which ${self} lives.

HERE
  if [ -n "${flag}" ]; then exit 0; else exit 1; fi
}

#
# Basic tools check
#
which -s which || { echo "No 'which' command."; exit 1; }
which -s basename || { echo "No 'basename' command."; exit 1; }
[ 0 -eq 0 ]    || { echo "The '[' command doesn't work."; exit 1; } # ]

#
# Process command line options
#
unset DST_DIR PYTHON

while getopts 'd:p:h?' c
  do
    case $c in
      d) DST_DIR=${OPTARG} ;;
      p) PYTHON=${OPTARG}  ;;
      h)                   ;&
      ?) usage help        ;;
    esac
  done
if [ -z "${DST_DIR}" ]; then echo "No directory provided."; usage; fi

#
# Determine pyton version and name of module to run
#
module="http.server"
which -s ${PYTHON}
if [ $? = 0 ]
  then
    ${PYTHON} --version 2>&1 | grep -e "^Python 2" > /dev/null
    if [ $? = 0 ]
      then
        module="SimpleHTTPServer"
      fi
    #
  else
    echo << HERE
No python command was found by the \`which ${PYTHON}\` command.

If python really is installed, ask your system administrator for the
name of the actual python interpreter binary, then edit "config.mk" and
set the PYTHON option to the actual name.  Include the full path if it
isn't in a directory listed in PATH.

If you are the system administrator, verify that a python interpreter is installed, and verify the name of python interpreter binary.

On Debian and Ubuntu systems:
    $ dpkg -L python-minimal | grep -w bin

On Red Hat and Fedora systems:
    $ rpm -q -l python | grep -w bin

On FreeBSD systems:
    $ pkg info -l python27 | grep -w bin

HERE
    exit 1
  fi

#
# Run the test Web server
#
echo ""
echo "    *********************************************"
echo "    *                                           *"
echo "    *  Press ^C to stop the testing web server  *"
echo "    *                                           *"
echo "    *********************************************"
echo ""
echo "         Browse to: http://127.0.0.1:8080/"
echo ""

cd ${DST_DIR}
${PYTHON} -m ${module} 8080
cd ${OLDPWD}

echo ""
echo "Test server stopped.  All work done."
echo ""
exit 0

