#
# Site-specific configuration options
#
# Edit this file if you want to change any of the default settings.
#


#
# All directory names in directory settings are relative to the
# directory in which Makefile and this config.mk file live.
#
# Leave off the trailing slash in directory name settings.
#


# Directory where source *.txt files live
#
# Notice: The subdirectory "sitemap" will be created and the files
# "sitemap/index.txt*" will be overwritten by the "sitemap" make target.
# Backups of "sitemap/index.txt" are saved with increasing numeric
# extensions from "sitemap/index.txt.0" through "sitemap/index.txt.999"
# before being deleted for good.
#
SRC_DIR = src


# Directory where destination files are staged for upload
#
# WARNING: FILES IN THIS DIRECTORY WILL BE DELETED AND/OR OVERWRITTEN
#
DST_DIR = stage


# Directory where site templates live
#
TPL_DIR = tpl


# Directory used for temporary storage during transformations
#
# WARNING: FILES IN THIS DIRECTORY WILL BE DELETED
#
TMP_DIR = temp


# Public file and assets directory, to be staged unmodified
#
PUB_DIR = pub


# Translation command and options
# The format of the full translation command is:
#
# ${XLAT} ${XLAT_OPTS1} sourcefile ${XLAT_OPTS2} destfile ${XLAT_OPTS3}
#
# WARNING: ONCE YOU CHOOSE A LIGHTWEIGHT MARKUP LANGUAGE (LML), YOU
# CAN'T CHANGE TO ANOTHER LML TRANSLATION COMMAND WITHOUT REWRITING ALL
# OF YOUR EXISTING CONTENT IN THE NEW LML.
#
# If your LML translation command leaves embedded HTML alone, you can
# mix your chosen LML and HTML together at your leisure.
# (reStructuredText does not: You need to use the ".. raw:: html"
# directive and indent your HTML by at least two spaces.)
#
# You can also embed M4 macros in your content, which will be processed
# before the LML translation command.  (If you do this, use the "-P"
# format of built-in M4 macros: "m4_dnl" instead of "dnl" for example.)
#
# If you write your site's content in raw HTML or M4 macros and don't
# need it to be translated, then use the following settings:
#
# XLAT       = cp
# XLAT_OPTS1 = -f
# XLAT_OPTS2 =
# XLAT_OPTS3 =
#
# You can use any lightweight markup language that generates and saves
# an HTML fragment instead of a complete HTML page.  The complete HTML
# page will be made from the "tpl/page.m4" template (or another template
# written in M4 macros).
#
# If you write your site's content in reStructuredText, make sure
# rst2html is installed and use the following settings:
#
# XLAT       = rst2html
#              # This template generates an expected HTML fragment:
# XLAT_OPTS1 = --template=${TPL_DIR}/rst2html.tpl
# XLAT_OPTS2 =
# XLAT_OPTS3 =
#
# If you write your site's content in txt2tags, make sure txt2tags is
# installed and use the following settings:
#
# XLAT       = txt2tags
# XLAT_OPTS1 = -t xhtml -H -q -i
# XLAT_OPTS2 = -o
# XLAT_OPTS3 =
#
# If you write your site's content in pandoc's flavor of markdown, make
# sure pandoc is installed and use the following settings:
#
# XLAT       = pandoc
# XLAT_OPTS1 = -f markdown -t html5
# XLAT_OPTS2 = -o
# XLAT_OPTS3 =
#
# (Be aware that pandoc and its dependencies can easily top 1-2 GB.)
#
# If you write your site's content in markdown and you use John Gruber's
# Markdown.pl script, you'll have to use the bin/markdown.sh script in
# this build system instead.  This is because markdown sends the HTML
# translation to stdout, and this build system can't redirect it to the
# right target automatically.  Use the following settings in this case:
#
#              # This build system's markdown translation script:
# XLAT       = bin/markdown.sh
#              # The actual markdown command and options:
# XLAT_OPTS1 = markdown
#              # Must be a literal lowercase F:
# XLAT_OPTS2 = f
#              # Must be a literal lowercase T:
# XLAT_OPTS3 = t
#
# If you use any other lightweight markup translation command that won't
# let you specify an output file name, adapt XLAT_OPTS1 above as needed.
#
XLAT       = bin/markdown.sh
XLAT_OPTS1 = markdown
XLAT_OPTS2 = f
XLAT_OPTS3 = t


# Options for the "upload" target.  Files staged in ${DST_DIR} will be
# uploaded via rsync (or another rsync command) to the live Web server.
#
# Edit these settings to match your own website host's settings.
#
# RSYNC      = rsync
# RSYNC_OPTS = -avkzh --delete --modify-window=1
# ADDRESS    = you@upload.your-website-host.com:~/path/to/your/site/root
#
# The --delete option is recommended for removing files in your live
# website that you delete or rename in your ${SRC_DIR} or ${PUB_DIR}.
#
# Without it, if you accidentally add ${PUB_DIR}/embarassing-info.csv
# then "make sync" and "make upload" before catching it, you would have
# to log in to your website server and delete it manually in addition to
# deleting it from your local ${PUB_DIR}.
#
# Also without it, if you write my-diary.txt in ${SRC_DIR}, decide later
# it should be my-unexpected-journey.txt, and later
# there-and-back-again.txt, and later again
# adventures-of-five-hobbits.txt, and finally
# the-downfall-of-the-lord-of-the-rings.txt, running "make pages" and
# "make upload" at least once between each rename, then your website
# would have all these extra pages served live instead of deleted:
#     my-diary.html
#     my-unexpected-journey.html
#     there-and-back-again.html
#     adventures-of-five-hobbits.html
# In addition to the page you actually expect to be live:
#     the-downfall-of-the-lord-of-the-rings.html
#
# The only significant drawback to having the --delete option in
# ${RSYNC_OPTS} is that on each "make upload", any files you manually
# uploaded to your website or downloaded into your website while logged
# into your website server will be deleted.
#
RSYNC      = rsync
RSYNC_OPTS = -avkzh --delete --modify-window=1
ADDRESS    = me@my-dreamhost-website.com:~/my-dreamhost-website.com


# Sitemap page title.
#
SITEMAP = Site Map


# Python binary name.  Normally "python" but not all Linux and Unix
# distributions call it that.
#
PYTHON = python



